..
    This file is part of Invenio.
    Copyright (C) 2016-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


================
 Invenio-XRootD
================

.. image:: https://github.com/inveniosoftware/invenio-xrootd/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-xrootd/actions

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-xrootd.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-xrootd

.. image:: https://img.shields.io/pypi/v/invenio-xrootd.svg
        :target: https://pypi.org/pypi/invenio-xrootd

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-xrootd.svg
        :target: https://github.com/inveniosoftware/invenio-xrootd/blob/master/LICENSE


XRootD file storage support for Invenio.

* Free software: MIT license
* Documentation: https://invenio-xrootd.readthedocs.io/
